Documentation
¶
Overview ¶
Package infoblox implements a DNS provider for solving the DNS-01 challenge using on prem infoblox DNS.
Index ¶
Constants ¶
const ( EnvHost = envNamespace + "HOST" EnvPort = envNamespace + "PORT" EnvUsername = envNamespace + "USERNAME" EnvPassword = envNamespace + "PASSWORD" EnvDNSView = envNamespace + "DNS_VIEW" EnvWApiVersion = envNamespace + "WAPI_VERSION" EnvSSLVerify = envNamespace + "SSL_VERIFY" EnvCACertificate = envNamespace + "CA_CERTIFICATE" EnvTTL = envNamespace + "TTL" EnvPropagationTimeout = envNamespace + "PROPAGATION_TIMEOUT" EnvPollingInterval = envNamespace + "POLLING_INTERVAL" EnvHTTPTimeout = envNamespace + "HTTP_TIMEOUT" )
Environment variables names.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// Host is the URL of the grid manager.
Host string
// Port is the Port for the grid manager.
Port string
// Username the user for accessing API.
Username string
// Password the password for accessing API.
Password string
// DNSView is the dns view to put new records and search from.
DNSView string
// WapiVersion is the version of web api used.
WapiVersion string
// SSLVerify is whether or not to verify the ssl of the server being hit.
SSLVerify bool
// CACertificate is the path to the CA certificate (PEM encoded).
CACertificate string
PropagationTimeout time.Duration
PollingInterval time.Duration
TTL int
HTTPTimeout int
}
Config is used to configure the creation of the DNSProvider.
func NewDefaultConfig ¶
func NewDefaultConfig() *Config
NewDefaultConfig returns a default configuration for the DNSProvider.
type DNSProvider ¶
type DNSProvider struct {
// contains filtered or unexported fields
}
DNSProvider implements the challenge.Provider interface.
func NewDNSProvider ¶
func NewDNSProvider() (*DNSProvider, error)
NewDNSProvider returns a DNSProvider instance configured for Infoblox. Credentials must be passed in the environment variables: INFOBLOX_USERNAME, INFOBLOX_PASSWORD INFOBLOX_HOST, INFOBLOX_PORT INFOBLOX_DNS_VIEW, INFOBLOX_WAPI_VERSION INFOBLOX_SSL_VERIFY.
func NewDNSProviderConfig ¶
func NewDNSProviderConfig(config *Config) (*DNSProvider, error)
NewDNSProviderConfig return a DNSProvider instance configured for HyperOne.
func (*DNSProvider) CleanUp ¶
func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error
CleanUp removes the TXT record matching the specified parameters.
func (*DNSProvider) Present ¶
func (d *DNSProvider) Present(domain, token, keyAuth string) error
Present creates a TXT record to fulfill the dns-01 challenge.
func (*DNSProvider) Timeout ¶
func (d *DNSProvider) Timeout() (timeout, interval time.Duration)
Timeout returns the timeout and interval to use when checking for DNS propagation.